# Copyright 2005, @Last Software, Inc.

# This software is provided as an example of using the Ruby interface
# to SketchUp.

# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted, provided that the above
# copyright notice appear in all copies.

# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#-----------------------------------------------------------------------------

require 'sketchup.rb'

#-----------------------------------------------------------------------------

# Adding one point does not increase size of bounding box. Must add at least 2
# points.

def newBoundingBoxTest
        bb = Geom:BoundingBox.new
        if (bb)
                UI.messagebox "Success"
        else
                UI.messagebox "Failure: Cannot Create Bounding Box"
        end

end

def addBoundingBoxTest

        point = Geom::Point3d.new(100,200,300)
        point2 = Geom::Point3d.new(300,200,100)
        model = Sketchup.active_model
        boundingbox = model.bounds
        # Returns a boundingbox
        bbox = boundingbox.add point
        bbox = boundingbox.add point2
        if (bbox)
            diagonal = boundingbox.diagonal
            UI.messagebox diagonal
        else
            UI.messagebox "Failure"
        end
end

def centerBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds
        # Returns a boundingbox
        point = boundingbox.center
        if (point)
            UI.messagebox point
        else
            UI.messagebox "Failure"
        end
end


def clearBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds
        # Returns an empty boundingbox.
        emptybb = boundingbox.clear
        if (emptybb)
            UI.messagebox emptybb
            begin
                diagonal = emptybb.diagonal
            rescue
                UI.messagebox $!.message
            end
            if (!diagonal)
                UI.messagebox "Success: No more Bounding Box"
            else
                UI.messagebox diagonal
            end
        else
            UI.messagebox "Failure"
        end
end

def containsBoundingBoxTest

        point = Geom::Point3d.new(100,200,300)
        model = Sketchup.active_model
        boundingbox = model.bounds
        # Returns a boundingbox
        bbox = boundingbox.add point
        status = bbox.contains? point
        if (status)
            UI.messagebox status
        else
            UI.messagebox "Failure"
        end

end

def cornerBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds
       
        point = boundingbox.corner(1)
        if (point)
            UI.messagebox point
        else
            UI.messagebox "Failure"
        end
end

def depthBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds
       
        depth = boundingbox.depth
        if (depth)
            UI.messagebox depth
        else
            UI.messagebox "Failure"
        end
end

def diagonalBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds
       
        diagonal = boundingbox.diagonal
        if (diagonal)
            UI.messagebox diagonal
        else
            UI.messagebox "Failure"
        end
end

def emptyBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds
       
        result = boundingbox.empty?
        if (result)
            UI.messagebox result
        else
            UI.messagebox result
        end
end

def heightBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds
       
        height = boundingbox.height
        if (height)
            UI.messagebox height
        else
            UI.messagebox "Failure"
        end
end

def maxBoundingBoxTest
       # width = 6
       # height = 5
       # depth = 4        
       model = Sketchup.active_model
       # entities = model.active_entities
       # group = entities.add_group
       # entities = group.entities    
      #  pts = []
       # pts[0] = [0, 0, 0]
       # pts[1] = [width, 0, 0]
       # pts[2] = [width, depth, 0]
       # pts[3] = [0, depth, 0]
       # base = entities.add_face pts
       # height = -height if( base.normal.dot(Z_AXIS) < 0 )
       # base.pushpull height
        boundingbox = model.bounds

        # Bug: Returns a huge negitive or positive number on the default model
        # bounding box. I would expect to return 0,0,0
        point = boundingbox.max
        if (point)
            UI.messagebox point
        else
            UI.messagebox "Failure"
        end
end

def minBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds
       
        point = boundingbox.min
        if (point)
            UI.messagebox point
        else
            UI.messagebox "Failure"
        end
end


def validBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds       
        status = boundingbox.valid?
        if (status)
            UI.messagebox status
        else
            UI.messagebox status
        end
end

def widthBoundingBoxTest
        width = 6
        height = 5
        depth = 4        
        model = Sketchup.active_model
        entities = model.active_entities
        group = entities.add_group
        entities = group.entities    
        pts = []
        pts[0] = [0, 0, 0]
        pts[1] = [width, 0, 0]
        pts[2] = [width, depth, 0]
        pts[3] = [0, depth, 0]
        base = entities.add_face pts
        height = -height if( base.normal.dot(Z_AXIS) < 0 )
        base.pushpull height
        boundingbox = model.bounds
       
        width = boundingbox.width
        if (width)
            UI.messagebox width
        else
            UI.messagebox "Failure"
        end
end



if( not file_loaded?("boundingboxtests.rb") )

    # This will add a separator to the menu, but only once
    add_separator_to_menu("Plugins")
    
    plugins_menu = UI.menu("Plugins")
    BoundingBoxTest_menu = plugins_menu.add_submenu("Bounding Box Tests")
    BoundingBoxTest_menu.add_item("Geom::BoundingBox.new") { newBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.add") { addBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.center") { centerBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.clear") { clearBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.contains") { containsBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.corner") { cornerBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.depth") { depthBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.diagonal") { diagonalBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.empty?") { emptyBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.height") { heightBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.max") { maxBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.min") { minBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.valid?") { validBoundingBoxTest }
    BoundingBoxTest_menu.add_item("BoundingBox.width") { widthBoundingBoxTest }

end

#-----------------------------------------------------------------------------
file_loaded("boundingboxtests.rb")

